ToolRack
========

|Latest Version| |Build Status| |Coverage Status| |Documentation Status|

A collection of utility functions and classes, and a few scripts too.


Documentation
-------------

API docs are available on ReadTheDocs_.


Installation
------------

ToolRack can be installed from PyPI_.

As a user run:

.. code:: bash

  $ pip install toolrack


Development installation
------------------------

The source tree is available available at
`<https://github.com/albertodonato/toolrack>`_, users should install
Virtualenv_ for development.

As a user run:

.. code:: bash

  $ virtualenv <target-dir>
  $ . <target-dir>/bin/activate
  $ git clone https://github.com/albertodonato/toolrack
  $ cd toolrack
  $ python setup.py develop


.. _ReadTheDocs: https://toolrack.readthedocs.io/en/latest/
.. _PyPI: https://pypi.python.org/
.. _Virtualenv: https://virtualenv.pypa.io/

.. |Latest Version| image:: https://img.shields.io/pypi/v/toolrack.svg
   :target: https://pypi.python.org/pypi/toolrack
.. |Build Status| image:: https://img.shields.io/travis/albertodonato/toolrack.svg
   :target: https://travis-ci.com/albertodonato/toolrack
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/albertodonato/toolrack/master.svg
   :target: https://codecov.io/gh/albertodonato/toolrack
.. |Documentation Status| image:: https://readthedocs.org/projects/toolrack/badge/?version=stable
   :target: https://toolrack.readthedocs.io/en/stable/?badge=stable
